@@ -6,7 +6,7 @@
 # scaling     - scale parameter
 # adj.order - vector of orders of polynomials to fit
 # adj.parm  - vector of parameters (a_j)
-adjfct.herm <- function(distance,scaling=1,adj.order,adj.parm=NULL,
+adjfct.herm <- function(distance, scaling=1, adj.order, adj.parm=NULL,
                         adj.exp=FALSE){
 
   # Check the adjustment parameters
@@ -18,11 +18,12 @@ adjfct.herm <- function(distance,scaling=1,adj.order,adj.parm=NULL,
 
   hermsum <- 0
 
-  for(i in 1:length(adj.order)){
-    hermsum <- hermsum + (adj.parm[i]*hermite.poly((distance/scaling),adj.order[i]))
+  for(i in seq_along(adj.order)){
+    hermsum <- hermsum + (adj.parm[i] * hermite.poly((distance/scaling),
+                                                     adj.order[i]))
   }
 
-  # if adj.exp return exp(hermsum) to keep f(x)>0 
+  # if adj.exp return exp(hermsum) to keep f(x)>0
   if(adj.exp){
     return(exp(hermsum))
   }else{
