@@ -13,7 +13,8 @@
 #' \item{\code{O1}}{systematic line placement, post-stratification with overlapping strata (akin to S1)}
 #' \item{\code{O2}}{systematic line placement, post-stratification with overlapping strata (weighted by line length per stratum, akin to S2)}
 #' \item{\code{O3}}{systematic line placement, post-stratification with overlapping strata, model-assisted estimator with trend in encounter rate with line length}
-#' \item{\code{P3}}{random point placement, potentially unequal number of visitsper point, model-based estimator}
+#' \item{\code{P2}}{random point placement, potentially unequal number of visits per point, design-based estimator}
+#' \item{\code{P3}}{random point placement, potentially unequal number of visits per point, model-based estimator}
 #' }
 #'
 #' Default value is \code{"R2"}, shown in Fewster et al. (2009) to have good performance for completely random designs for lines. For systematic parallel line transect designs, Fewster et al. recommend \code{"O2"}. For point transects the default (and currently only implemented option) is \code{"P3"}.
@@ -36,6 +37,7 @@
 #'   Jupp, J.L. Laake and L. Thomas. 2009. Estimating the encounter rate
 #'   variance in distance sampling. Biometrics 65: 225-236.
 #' @keywords utility
+#' @export
 varn <- function(lvec, nvec, type){
   #  Function courtesy of Rachel Fewster with a few minor changes
 
@@ -44,7 +46,7 @@ varn <- function(lvec, nvec, type){
   k <- length(lvec)
 
   ## Go through the estimators one by one.
-  if(!(type %in% c("R2", "R3", "R4", "S1", "S2", "O1", "O2", "O3", "P3")))
+  if(!(type %in% c("R2", "R3", "R4", "S1", "S2", "O1", "O2", "O3", "P2", "P3")))
     stop (paste("Encounter rate variance type '", type,
                 "' is not recognized.", sep=""))
 
@@ -60,6 +62,11 @@ varn <- function(lvec, nvec, type){
     return(var.R2)
   }
 
+  if(type=="P2"){
+    var.P2 <- (1/(k*(k-1))) * sum((nvec/lvec - 1/k * sum(nvec/lvec))^2)
+    return(var.P2)
+  }
+
   ## Estimator R3 or P3
   if(type=="R3" | type=="P3"){
     var.R3 <- 1/(L * (k - 1)) * sum(lvec * (nvec/lvec - ntot/L)^2)
